#
# spec file for package e_dbus
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           e_dbus
Version:        1.7.4
Release:        11.1
Summary:        Dbus wrapping and glue layer library
License:        BSD-2-Clause
Group:          System/Libraries
Url:            http://enlightenment.org/
Source:         %{name}-%{version}.tar.bz2
BuildRequires:  dbus-devel
BuildRequires:  doxygen
BuildRequires:  ecore-devel
BuildRequires:  eina-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig
%if 0%{?suse_version}
BuildRequires:  fdupes
%endif
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
E_Dbus is a set of wrappers around DBus APIs by third party, so they can be
easily used by EFL applications, automatically providing Ecore/main loop
integration, as well as Eina data types.

%package -n libedbus1
Summary:        E_Dbus Dynamic Library
Group:          System/Libraries

%description -n libedbus1
Main dynamic library of E_Dbus.

%package devel
Summary:        E_Dbus development package
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       dbus-devel
Requires:       ecore-devel
Requires:       eina-devel
Requires:       libedbus1 = %{version}

%description devel
Development files for E_Dbus package.

%package doc-html
Summary:        HTML documentation of Eet
Group:          Documentation/HTML

%description doc-html
Documentation of Eet library in form of HTML pages.

%prep
%setup -q

%build
# fake time used for documentation
FAKE_DOCDATE=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y')
FAKE_DOCYEAR=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%Y')
FAKE_DOCDATETIME=$(LC_ALL=C date -u -r %{_sourcedir}/%{name}.changes '+%%a %%b %%d %%Y %T')
sed -i "s/\$datetime/$FAKE_DOCDATETIME/g;s/\$date/$FAKE_DOCDATE/g;s/\$year/$FAKEDOCYEAR/g" doc/*.html

%configure --disable-static --disable-silent-rules
make %{?_smp_mflags}
make doc

%install
make install DESTDIR="%buildroot"

# copy documentation manually
echo "Copying HTML documentation"
mkdir -p %{buildroot}%{_docdir}/%{name}
/bin/cp -vr doc/html %{buildroot}%{_docdir}/%{name}
# fix permissions
find %{buildroot}%{_docdir} -type f | xargs chmod 0644
find %{buildroot}%{_docdir} -type d | xargs chmod 0755
# remove duplicates
%if 0%{?suse_version}
%fdupes -s %{buildroot}%{_docdir}
%endif

find %{buildroot}%{_libdir} -name '*.la' -exec rm -v {} \;
cp -v ChangeLog README COPYING %{buildroot}%{_docdir}/%{name}

%post -n libedbus1 -p /sbin/ldconfig

%postun -n libedbus1 -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc %{_docdir}/%{name}
%{_docdir}/%{name}
%exclude %{_docdir}/%{name}/html
%{_bindir}/e*
%{_datadir}/e_dbus/

%files -n libedbus1
%defattr(-, root, root)
%{_libdir}/libe*.so.*

%files devel
%defattr(-, root, root)
%{_includedir}/e_dbus-1/
%{_libdir}/pkgconfig/*.pc
%{_libdir}/libe*.so

%files doc-html
%defattr(-, root, root)
%doc %{_docdir}/%{name}/html

%changelog
* Sat Dec 22 2012       Andrew Wyatt <andrew@fuduntu.org> - 1.7.4-11.1
- Built for Fuduntu

* Fri Dec 21 2012 sleep_walker@suse.cz
- update to 1.7.4
  Changes since E_dbus 1.7.3:
  * Add XML output to doc
  * Add installation rule for doc
* Fri Dec 21 2012 sleep_walker@suse.cz
- use vicious %%doc macro again, but now it will work, I promise
* Fri Dec 21 2012 sleep_walker@suse.cz
- remove vicious %%doc macro
* Thu Dec 20 2012 sleep_walker@suse.cz
- build and package documentation
* Sat Dec  8 2012 simon@simotek.net
- Bump to 1.7.3
- 1.7.3 is a bugfix release to coincide with the beta release of efl
* Fri Nov 23 2012 simon@simotek.net
- bump to 1.7.2
- 1.7.2 is required to build and use the latest e17 alpha's
  (no real changes, but keeping EFL version numbers synced)
* Thu Nov 22 2012 sleep_walker@suse.cz
- improve summaries and descriptions
- fix license
- clean the spec a bit
* Wed Nov 21 2012 sleep_walker@suse.cz
- add --disable-static-rules to configure
- remove autoupdate entries from changelog
* Thu Nov 15 2012 sleep_walker@suse.cz
- remove autoreconf as it is not needed for release
* Sun Oct 21 2012 simon@simotek.net
- bump to 1.7.1
* Thu Sep 20 2012 sleep_walker@suse.cz
- change pkgconfig dependency to package name
* Fri Sep  7 2012 sleep_walker@suse.cz
- revert spec file change makeinstall --> make_install
* Fri Dec 30 2011 sleep_walker@suse.cz
- explicitly BuildRequire autoconf, automake and libtool
* Mon Dec 12 2011 sleep_walker@suse.cz
- add new file - logo.png into e_dbus package
* Sat Nov 19 2011 tcech@suse.com
- add e_dbus as required dependency of e_dbus-devel
* Tue Nov  8 2011 tcech@suse.com
- fix placement of autoreconf for Mandrivas
* Sat Oct 15 2011 tcech@suse.com
- add devel packages required to build as required for devel package
* Wed Sep 28 2011 tcech@suse.com
- change pkgconfig dependencies to package names
* Tue Sep 27 2011 jreidinger@suse.com
- version update to 1.0.1
- clean up spec file
* Tue Feb  1 2011 dimstar@opensuse.org
- Initial package, version 1.0.0
